@@ -75,8 +75,7 @@ class NeteaseProvider(AbstractProvider, ProviderV2):
             user_data = comment_data['user']
             user = BriefUserModel(identifier=str(user_data['userId']),
                                   source='netease',
-                                  name=user_data['nickname'],
-                                  avatar_url=user_data['avatarUrl'])
+                                  name=user_data['nickname'])
             be_replied = comment_data['beReplied']
             if be_replied:
                 replied_comment_data = be_replied[0]
@@ -158,7 +157,7 @@ class NeteaseProvider(AbstractProvider, ProviderV2):
             }
 
             # Trick: try to find the highest quality url
-            # When the song is only for vip/payed user and current user is non-vip,
+            # When the song is only for vip/paid user and current user is non-vip,
             # the highest bitrate is 0, which means this song is unavailable
             # for current user.
             songs_url_data = self.api.weapi_songs_url([song_id], 999000)
